# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.messages_api import MessagesApi


class TestMessagesApi(unittest.TestCase):
    """ MessagesApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.messages_api.MessagesApi()

    def tearDown(self):
        pass

    def test_create(self):
        """
        Test case for create

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
