# coding: utf-8

"""
    API BIS-сервиса \"Telegram\"

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.data import Data

# import apis into sdk package
from .apis.messages_api import MessagesApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()
